@@ -1,5 +1,5 @@
 ## no critic
-# $Id: /local/Mango/trunk/lib/Mango/I18N/ru.pm 150 2007-04-14T02:57:04.324056Z claco  $
+# $Id$
 package Mango::I18N::ru;
 use strict;
 use warnings;
@@ -12,13 +12,6 @@ BEGIN {
 
 %Lexicon = (
     Language => 'русском',
-
-    "RESOURCE_NOT_FOUND" =>
-        "Ресурсов не найдено",
-
-    "RESOURCE_NOT_FOUND_MESSAGE" =>
-        "Запрашиваемый ресурс не найден на этом сервере.",
-
 );
 
 1;
@@ -28,6 +21,23 @@ __END__
 
 Mango::I18N::ru - Mango Language Pack: Russian
 
+=head1 SYNOPSIS
+
+    use Mango::I18N qw/translate/;
+
+    {
+        local $ENV{'LANG'} = 'ru';
+        print translate('Hello');
+    };
+
+=head1 DESCRIPTION
+
+Mango::I18N::ru contains all of the messages used in Mango in Russian.
+
+=head1 SEE ALSO
+
+L<Mango::I18N>
+
 =head1 AUTHOR
 
     Christopher H. Laco
